# remirepo spec file for php-pecl-ps
#
# Copyright (c) 2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:          %scl_package        php-pecl-ps}

%global with_zts  0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name ps
# After 20-gd.ini
%global ini_name  40-%{pecl_name}.ini

Summary:        An extension to create PostScript files
Name:           %{?scl_prefix}php-pecl-ps
Version:        1.4.3
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        PHP
Group:          Development/Languages
URL:            https://pecl.php.net/package/%{pecl_name}

Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-gd
BuildRequires:  pkgconfig(gdlib) >= 2.1.1
BuildRequires:  pkgconfig(libps)

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%if "%{php_version}" > "8.0"
Requires:       %{?scl_prefix}php-gd%{?_isa}
%endif
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.4"
Obsoletes:     php74-pecl-%{pecl_name}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:     php80-pecl-%{pecl_name}
%endif
%if "%{php_version}" > "8.1"
Obsoletes:     php81-pecl-%{pecl_name}
%endif
%endif


%description
Ps is an extension similar to the pdf extension but for creating PostScript
files. Its api is modelled after the pdf extension.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -c -q

mv %{pecl_name}-%{version} NTS

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

pushd NTS
%if "%{php_version}" < "8.0"
# https://github.com/steinm/ps/issues/1
sed -e 's/HAVE_LIBGD/DISABLE_LIBGD/' -i *.c
sed -e '/GDLIB/d' -i config.m4
%endif

# Check version
extver=$(sed -n '/#define PHP_PS_VERSION/{s/.* "//;s/".*$//;p}' php_ps.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream version is ${extver}, expecting %{version}.
   exit 1
fi
popd

%if %{with_zts}
cp -pr NTS ZTS
%endif

# Create the config file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
  --with-ps \
%if "%{php_version}" > "8.0"
  --enable-gd \
%else
  --disable-gd \
%endif
  --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%{__php} --no-php-ini \
%if "%{php_version}" > "8.0"
    --define extension=gd \
%endif
    --define extension=modules/%{pecl_name}.so \
    --ri %{pecl_name}

%{__php} --no-php-ini \
%if "%{php_version}" > "8.0"
    --define extension=gd \
%endif
    --define extension=modules/%{pecl_name}.so \
    --re %{pecl_name} >REFLECTION

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
  --with-ps \
%if "%{php_version}" > "8.0"
  --enable-gd \
%else
  --disable-gd \
%endif
  --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install-modules INSTALL_ROOT=%{buildroot}

# Drop in the bit of configuration
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install-modules INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd NTS
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//') REFLECTION
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
OPT="-n"
%if "%{php_version}" > "8.0"
    OPT="$OPT -d extension=gd"
%endif

: Minimal load test for NTS extension
cd NTS
%{_bindir}/php $OPT \
    --define extension=modules/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/php \
TEST_PHP_ARGS="$OPT -d extension=$PWD/modules/%{pecl_name}.so" \
%{_bindir}/php -n run-tests.php -q --show-diff


%if %{with_zts}
: Minimal load test for ZTS extension
cd ../ZTS
%{__ztsphp} $OPT \
    --define extension=modules/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="$OPT -d extension=$PWD/modules/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Sep 28 2021 Remi Collet <remi@remirepo.net> - 1.4.3-1
- update to 1.4.3
- add REFLECTION file to package documentation
- License is PHP
- Enable GD support with PHP 8 only

* Sun Sep 26 2021 Remi Collet <remi@remirepo.net> - 1.4.2-1
- new package
- open https://github.com/steinm/ps/pull/2 cleanup
- open https://github.com/steinm/ps/issues/1 broken build with gd
- open https://github.com/steinm/ps/issues/3 missing LICENSE file
